@@ -101,9 +101,17 @@ bool KCategorizedViewPrivate::isCategorized() const
     return proxyModel && categoryDrawer && proxyModel->isCategorizedModel();
 }
 
+QStyleOptionViewItem KCategorizedViewPrivate::viewOpts()
+{
+    QStyleOptionViewItem option;
+    q->initViewItemOption(&option);
+    return option;
+}
+
 QStyleOptionViewItem KCategorizedViewPrivate::blockRect(const QModelIndex &representative)
 {
-    QStyleOptionViewItem option(q->viewOptions());
+    QStyleOptionViewItem option = viewOpts();
+
     const int height = categoryDrawer->categoryHeight(representative, option);
     const QString categoryDisplay = representative.data(KCategorizedSortFilterProxyModel::CategoryDisplayRole).toString();
     QPoint pos = blockPosition(categoryDisplay);
@@ -116,7 +124,7 @@ QStyleOptionViewItem KCategorizedViewPrivate::blockRect(const QModelIndex &repre
     return option;
 }
 
-QPair<QModelIndex, QModelIndex> KCategorizedViewPrivate::intersectingIndexesWithRect(const QRect &_rect) const
+std::pair<QModelIndex, QModelIndex> KCategorizedViewPrivate::intersectingIndexesWithRect(const QRect &_rect) const
 {
     const int rowCount = proxyModel->rowCount();
 
@@ -154,7 +162,7 @@ QPair<QModelIndex, QModelIndex> KCategorizedViewPrivate::intersectingIndexesWith
 
     const QModelIndex topIndex = proxyModel->index(top, q->modelColumn(), q->rootIndex());
 
-    return qMakePair(bottomIndex, topIndex);
+    return {bottomIndex, topIndex};
 }
 
 QPoint KCategorizedViewPrivate::blockPosition(const QString &category)
@@ -175,7 +183,8 @@ QPoint KCategorizedViewPrivate::blockPosition(const QString &category)
         if (index.row() < categoryIndex.row()) {
             continue;
         }
-        res.ry() += categoryDrawer->categoryHeight(categoryIndex, q->viewOptions()) + categorySpacing;
+
+        res.ry() += categoryDrawer->categoryHeight(categoryIndex, viewOpts()) + categorySpacing;
         if (index.row() == categoryIndex.row()) {
             continue;
         }
@@ -752,7 +761,7 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
         return;
     }
 
-    const QPair<QModelIndex, QModelIndex> intersecting = d->intersectingIndexesWithRect(viewport()->rect().intersected(event->rect()));
+    const std::pair<QModelIndex, QModelIndex> intersecting = d->intersectingIndexesWithRect(viewport()->rect().intersected(event->rect()));
 
     QPainter p(viewport());
     p.save();
@@ -764,7 +773,8 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
     while (it != d->blocks.constEnd()) {
         const KCategorizedViewPrivate::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        QStyleOptionViewItem option(viewOptions());
+
+        QStyleOptionViewItem option = d->viewOpts();
         option.features |= d->alternatingBlockColors && block.alternate //
             ? QStyleOptionViewItem::Alternate
             : QStyleOptionViewItem::None;
@@ -814,7 +824,7 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
 
             const QModelIndex index = d->proxyModel->index(i, modelColumn(), rootIndex());
             const Qt::ItemFlags flags = d->proxyModel->flags(index);
-            QStyleOptionViewItem option(viewOptions());
+            QStyleOptionViewItem option(d->viewOpts());
             option.rect = visualRect(index);
             option.widget = this;
             option.features |= wordWrap() ? QStyleOptionViewItem::WrapText : QStyleOptionViewItem::None;
@@ -831,7 +841,7 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
                 option.state |= (index == d->hoveredIndex) ? QStyle::State_MouseOver : QStyle::State_None;
             }
 
-            itemDelegate(index)->paint(&p, option, index);
+            itemDelegateForIndex(index)->paint(&p, option, index);
             ++i;
         }
         // END: draw items
@@ -872,7 +882,7 @@ void KCategorizedView::setSelection(const QRect &rect, QItemSelectionModel::Sele
         return;
     }
 
-    const QPair<QModelIndex, QModelIndex> intersecting = d->intersectingIndexesWithRect(rect);
+    const std::pair<QModelIndex, QModelIndex> intersecting = d->intersectingIndexesWithRect(rect);
 
     QItemSelection selection;
 
@@ -923,7 +933,7 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
     while (it != d->blocks.constEnd()) {
         const KCategorizedViewPrivate::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
-        QStyleOptionViewItem option(viewOptions());
+        QStyleOptionViewItem option(d->viewOpts());
         const int height = d->categoryDrawer->categoryHeight(categoryIndex, option);
         QPoint pos = d->blockPosition(it.key());
         pos.ry() -= height;
@@ -1043,7 +1053,7 @@ void KCategorizedView::startDrag(Qt::DropActions supportedActions)
 void KCategorizedView::dragMoveEvent(QDragMoveEvent *event)
 {
     QListView::dragMoveEvent(event);
-    d->hoveredIndex = indexAt(event->pos());
+    d->hoveredIndex = indexAt(event->position().toPoint());
 }
 
 void KCategorizedView::dragEnterEvent(QDragEnterEvent *event)
@@ -1400,7 +1410,7 @@ void KCategorizedView::currentChanged(const QModelIndex &current, const QModelIn
     QListView::currentChanged(current, previous);
 }
 
-void KCategorizedView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
+void KCategorizedView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QList<int> &roles)
 {
     QListView::dataChanged(topLeft, bottomRight, roles);
     if (!d->isCategorized()) {
@@ -1443,24 +1453,6 @@ void KCategorizedView::rowsInserted(const QModelIndex &parent, int start, int en
     d->rowsInserted(parent, start, end);
 }
 
-#if KITEMVIEWS_BUILD_DEPRECATED_SINCE(4, 4)
-void KCategorizedView::rowsInsertedArtifficial(const QModelIndex &parent, int start, int end)
-{
-    Q_UNUSED(parent);
-    Q_UNUSED(start);
-    Q_UNUSED(end);
-}
-#endif
-
-#if KITEMVIEWS_BUILD_DEPRECATED_SINCE(4, 4)
-void KCategorizedView::rowsRemoved(const QModelIndex &parent, int start, int end)
-{
-    Q_UNUSED(parent);
-    Q_UNUSED(start);
-    Q_UNUSED(end);
-}
-#endif
-
 void KCategorizedView::slotLayoutChanged()
 {
     if (!d->isCategorized()) {
