@@ -9,34 +9,30 @@
 
 #include "ktreewidgetsearchline.h"
 
-#include <QList>
-#include <QTimer>
+#include <QActionGroup>
 #include <QApplication>
 #include <QContextMenuEvent>
 #include <QHeaderView>
-#include <QLineEdit>
+#include <QList>
 #include <QMenu>
+#include <QTimer>
 #include <QTreeWidget>
 
-class Q_DECL_HIDDEN KTreeWidgetSearchLine::Private
+class KTreeWidgetSearchLinePrivate
 {
 public:
-    Private(KTreeWidgetSearchLine *_q)
-        : q(_q),
-          caseSensitive(Qt::CaseInsensitive),
-          keepParentsVisible(true),
-          canChooseColumns(true),
-          queuedSearches(0)
+    KTreeWidgetSearchLinePrivate(KTreeWidgetSearchLine *_q)
+        : q(_q)
     {
     }
 
-    KTreeWidgetSearchLine *q;
+    KTreeWidgetSearchLine *const q;
     QList<QTreeWidget *> treeWidgets;
-    Qt::CaseSensitivity caseSensitive;
-    bool keepParentsVisible;
-    bool canChooseColumns;
+    Qt::CaseSensitivity caseSensitive = Qt::CaseInsensitive;
+    bool keepParentsVisible = true;
+    bool canChooseColumns = true;
     QString search;
-    int queuedSearches;
+    int queuedSearches = 0;
     QList<int> searchColumns;
 
     void _k_rowsInserted(const QModelIndex &parent, int start, int end) const;
@@ -65,7 +61,7 @@ public:
     }
 };
 
-void KTreeWidgetSearchLine::Private::_k_rowsInserted(const QModelIndex &parentIndex, int start, int end) const
+void KTreeWidgetSearchLinePrivate::_k_rowsInserted(const QModelIndex &parentIndex, int start, int end) const
 {
     QAbstractItemModel *model = qobject_cast<QAbstractItemModel *>(q->sender());
     if (!model) {
@@ -73,11 +69,12 @@ void KTreeWidgetSearchLine::Private::_k_rowsInserted(const QModelIndex &parentIn
     }
 
     QTreeWidget *widget = nullptr;
-    for (QTreeWidget *tree : qAsConst(treeWidgets))
+    for (QTreeWidget *tree : std::as_const(treeWidgets)) {
         if (tree->model() == model) {
             widget = tree;
             break;
         }
+    }
 
     if (!widget) {
         return;
@@ -89,19 +86,19 @@ void KTreeWidgetSearchLine::Private::_k_rowsInserted(const QModelIndex &parentIn
             bool newHidden = !q->itemMatches(item, q->text());
             if (item->isHidden() != newHidden) {
                 item->setHidden(newHidden);
-                emit q->hiddenChanged(item, newHidden);
+                Q_EMIT q->hiddenChanged(item, newHidden);
             }
         }
     }
 }
 
-void KTreeWidgetSearchLine::Private::_k_treeWidgetDeleted(QObject *object)
+void KTreeWidgetSearchLinePrivate::_k_treeWidgetDeleted(QObject *object)
 {
     treeWidgets.removeAll(static_cast<QTreeWidget *>(object));
     q->setEnabled(treeWidgets.isEmpty());
 }
 
-void KTreeWidgetSearchLine::Private::_k_slotColumnActivated(QAction *action)
+void KTreeWidgetSearchLinePrivate::_k_slotColumnActivated(QAction *action)
 {
     if (!action) {
         return;
@@ -145,7 +142,7 @@ void KTreeWidgetSearchLine::Private::_k_slotColumnActivated(QAction *action)
     q->updateSearch();
 }
 
-void KTreeWidgetSearchLine::Private::_k_slotAllVisibleColumns()
+void KTreeWidgetSearchLinePrivate::_k_slotAllVisibleColumns()
 {
     if (searchColumns.isEmpty()) {
         searchColumns.append(0);
@@ -160,19 +157,19 @@ void KTreeWidgetSearchLine::Private::_k_slotAllVisibleColumns()
 // private methods
 ////////////////////////////////////////////////////////////////////////////////
 
-void KTreeWidgetSearchLine::Private::checkColumns()
+void KTreeWidgetSearchLinePrivate::checkColumns()
 {
     canChooseColumns = q->canChooseColumnsCheck();
 }
 
-void KTreeWidgetSearchLine::Private::checkItemParentsNotVisible(QTreeWidget *treeWidget)
+void KTreeWidgetSearchLinePrivate::checkItemParentsNotVisible(QTreeWidget *treeWidget)
 {
     for (QTreeWidgetItemIterator it(treeWidget); *it; ++it) {
         QTreeWidgetItem *item = *it;
         bool newHidden = !q->itemMatches(item, search);
         if (item->isHidden() != newHidden) {
             item->setHidden(newHidden);
-            emit q->hiddenChanged(item, newHidden);
+            Q_EMIT q->hiddenChanged(item, newHidden);
         }
     }
 }
@@ -184,7 +181,7 @@ void KTreeWidgetSearchLine::Private::checkItemParentsNotVisible(QTreeWidget *tre
  *  \return \c true if an item which should be visible is found, \c false if all items found should be hidden. If this function
  *             returns true and \p highestHiddenParent was not 0, highestHiddenParent will have been shown.
  */
-bool KTreeWidgetSearchLine::Private::checkItemParentsVisible(QTreeWidgetItem *item)
+bool KTreeWidgetSearchLinePrivate::checkItemParentsVisible(QTreeWidgetItem *item)
 {
     bool childMatch = false;
     for (int i = 0; i < item->childCount(); ++i) {
@@ -195,7 +192,7 @@ bool KTreeWidgetSearchLine::Private::checkItemParentsVisible(QTreeWidgetItem *it
     bool newHidden = !childMatch && !q->itemMatches(item, search);
     if (item->isHidden() != newHidden) {
         item->setHidden(newHidden);
-        emit q->hiddenChanged(item, newHidden);
+        Q_EMIT q->hiddenChanged(item, newHidden);
     }
 
     return !newHidden;
@@ -206,13 +203,13 @@ bool KTreeWidgetSearchLine::Private::checkItemParentsVisible(QTreeWidgetItem *it
 ////////////////////////////////////////////////////////////////////////////////
 
 KTreeWidgetSearchLine::KTreeWidgetSearchLine(QWidget *q, QTreeWidget *treeWidget)
-    : QLineEdit(q), d(new Private(this))
+    : QLineEdit(q)
+    , d(new KTreeWidgetSearchLinePrivate(this))
 {
-    connect(this, SIGNAL(textChanged(QString)),
-            this, SLOT(_k_queueSearch(QString)));
+    connect(this, SIGNAL(textChanged(QString)), this, SLOT(_k_queueSearch(QString)));
 
     setClearButtonEnabled(true);
-    setPlaceholderText(tr("Search..."));
+    setPlaceholderText(tr("Search...", "@info:placeholder"));
     setTreeWidget(treeWidget);
 
     if (!treeWidget) {
@@ -220,21 +217,17 @@ KTreeWidgetSearchLine::KTreeWidgetSearchLine(QWidget *q, QTreeWidget *treeWidget
     }
 }
 
-KTreeWidgetSearchLine::KTreeWidgetSearchLine(QWidget *q,
-        const QList<QTreeWidget *> &treeWidgets)
-    : QLineEdit(q), d(new Private(this))
+KTreeWidgetSearchLine::KTreeWidgetSearchLine(QWidget *q, const QList<QTreeWidget *> &treeWidgets)
+    : QLineEdit(q)
+    , d(new KTreeWidgetSearchLinePrivate(this))
 {
-    connect(this, SIGNAL(textChanged(QString)),
-            this, SLOT(_k_queueSearch(QString)));
+    connect(this, SIGNAL(textChanged(QString)), this, SLOT(_k_queueSearch(QString)));
 
     setClearButtonEnabled(true);
     setTreeWidgets(treeWidgets);
 }
 
-KTreeWidgetSearchLine::~KTreeWidgetSearchLine()
-{
-    delete d;
-}
+KTreeWidgetSearchLine::~KTreeWidgetSearchLine() = default;
 
 Qt::CaseSensitivity KTreeWidgetSearchLine::caseSensitivity() const
 {
@@ -305,7 +298,7 @@ void KTreeWidgetSearchLine::updateSearch(const QString &pattern)
 {
     d->search = pattern.isNull() ? text() : pattern;
 
-    for (QTreeWidget *treeWidget : qAsConst(d->treeWidgets)) {
+    for (QTreeWidget *treeWidget : std::as_const(d->treeWidgets)) {
         updateSearch(treeWidget);
     }
 }
@@ -321,11 +314,11 @@ void KTreeWidgetSearchLine::updateSearch(QTreeWidget *treeWidget)
 
     QTreeWidgetItem *currentItem = treeWidget->currentItem();
 
-    if (d->keepParentsVisible)
+    if (d->keepParentsVisible) {
         for (int i = 0; i < treeWidget->topLevelItemCount(); ++i) {
             d->checkItemParentsVisible(treeWidget->topLevelItem(i));
         }
-    else {
+    } else {
         d->checkItemParentsNotVisible(treeWidget);
     }
 
@@ -333,7 +326,7 @@ void KTreeWidgetSearchLine::updateSearch(QTreeWidget *treeWidget)
         treeWidget->scrollToItem(currentItem);
     }
 
-    emit searchUpdated(d->search);
+    Q_EMIT searchUpdated(d->search);
 }
 
 void KTreeWidgetSearchLine::setCaseSensitivity(Qt::CaseSensitivity caseSensitive)
@@ -367,13 +360,13 @@ void KTreeWidgetSearchLine::setTreeWidget(QTreeWidget *treeWidget)
 
 void KTreeWidgetSearchLine::setTreeWidgets(const QList<QTreeWidget *> &treeWidgets)
 {
-    for (QTreeWidget *treeWidget : qAsConst(d->treeWidgets)) {
+    for (QTreeWidget *treeWidget : std::as_const(d->treeWidgets)) {
         disconnectTreeWidget(treeWidget);
     }
 
     d->treeWidgets = treeWidgets;
 
-    for (QTreeWidget *treeWidget : qAsConst(d->treeWidgets)) {
+    for (QTreeWidget *treeWidget : std::as_const(d->treeWidgets)) {
         connectTreeWidget(treeWidget);
     }
 
@@ -398,15 +391,15 @@ bool KTreeWidgetSearchLine::itemMatches(const QTreeWidgetItem *item, const QStri
     if (!d->searchColumns.isEmpty()) {
         QList<int>::ConstIterator it = d->searchColumns.constBegin();
         for (; it != d->searchColumns.constEnd(); ++it) {
-            if (*it < item->treeWidget()->columnCount() &&
-                    item->text(*it).indexOf(pattern, 0, d->caseSensitive) >= 0) {
+            if (*it < item->treeWidget()->columnCount() //
+                && item->text(*it).indexOf(pattern, 0, d->caseSensitive) >= 0) {
                 return true;
             }
         }
     } else {
         for (int i = 0; i < item->treeWidget()->columnCount(); i++) {
-            if (item->treeWidget()->columnWidth(i) > 0 &&
-                    item->text(i).indexOf(pattern, 0, d->caseSensitive) >= 0) {
+            if (item->treeWidget()->columnWidth(i) > 0 //
+                && item->text(i).indexOf(pattern, 0, d->caseSensitive) >= 0) {
                 return true;
             }
         }
@@ -421,10 +414,9 @@ void KTreeWidgetSearchLine::contextMenuEvent(QContextMenuEvent *event)
 
     if (d->canChooseColumns) {
         popup->addSeparator();
-        QMenu *subMenu = popup->addMenu(tr("Search Columns"));
+        QMenu *subMenu = popup->addMenu(tr("Search Columns", "@title:menu"));
 
-        QAction *allVisibleColumnsAction = subMenu->addAction(tr("All Visible Columns"),
-                                           this, SLOT(_k_slotAllVisibleColumns()));
+        QAction *allVisibleColumnsAction = subMenu->addAction(tr("All Visible Columns", "@optipn:check"), this, SLOT(_k_slotAllVisibleColumns()));
         allVisibleColumnsAction->setCheckable(true);
         allVisibleColumnsAction->setChecked(d->searchColumns.isEmpty());
         subMenu->addSeparator();
@@ -433,7 +425,7 @@ void KTreeWidgetSearchLine::contextMenuEvent(QContextMenuEvent *event)
 
         QActionGroup *group = new QActionGroup(popup);
         group->setExclusive(false);
-        connect(group, SIGNAL(triggered(QAction*)), SLOT(_k_slotColumnActivated(QAction*)));
+        connect(group, SIGNAL(triggered(QAction *)), SLOT(_k_slotColumnActivated(QAction *)));
 
         QHeaderView *const header = d->treeWidgets.first()->header();
         for (int j = 0; j < header->count(); j++) {
@@ -471,20 +463,16 @@ void KTreeWidgetSearchLine::contextMenuEvent(QContextMenuEvent *event)
 
 void KTreeWidgetSearchLine::connectTreeWidget(QTreeWidget *treeWidget)
 {
-    connect(treeWidget, SIGNAL(destroyed(QObject*)),
-            this, SLOT(_k_treeWidgetDeleted(QObject*)));
+    connect(treeWidget, SIGNAL(destroyed(QObject *)), this, SLOT(_k_treeWidgetDeleted(QObject *)));
 
-    connect(treeWidget->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(_k_rowsInserted(QModelIndex,int,int)));
+    connect(treeWidget->model(), SIGNAL(rowsInserted(QModelIndex, int, int)), this, SLOT(_k_rowsInserted(QModelIndex, int, int)));
 }
 
 void KTreeWidgetSearchLine::disconnectTreeWidget(QTreeWidget *treeWidget)
 {
-    disconnect(treeWidget, SIGNAL(destroyed(QObject*)),
-               this, SLOT(_k_treeWidgetDeleted(QObject*)));
+    disconnect(treeWidget, SIGNAL(destroyed(QObject *)), this, SLOT(_k_treeWidgetDeleted(QObject *)));
 
-    disconnect(treeWidget->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-               this, SLOT(_k_rowsInserted(QModelIndex,int,int)));
+    disconnect(treeWidget->model(), SIGNAL(rowsInserted(QModelIndex, int, int)), this, SLOT(_k_rowsInserted(QModelIndex, int, int)));
 }
 
 bool KTreeWidgetSearchLine::canChooseColumnsCheck()
@@ -534,14 +522,13 @@ bool KTreeWidgetSearchLine::canChooseColumnsCheck()
 
 bool KTreeWidgetSearchLine::event(QEvent *event)
 {
-
     if (event->type() == QEvent::KeyPress) {
         QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
-        if (keyEvent->matches(QKeySequence::MoveToNextLine) || keyEvent->matches(QKeySequence::SelectNextLine) ||
-                keyEvent->matches(QKeySequence::MoveToPreviousLine) || keyEvent->matches(QKeySequence::SelectPreviousLine) ||
-                keyEvent->matches(QKeySequence::MoveToNextPage) ||  keyEvent->matches(QKeySequence::SelectNextPage) ||
-                keyEvent->matches(QKeySequence::MoveToPreviousPage) ||  keyEvent->matches(QKeySequence::SelectPreviousPage) ||
-                keyEvent->key() == Qt::Key_Enter || keyEvent->key() == Qt::Key_Return) {
+        if (keyEvent->matches(QKeySequence::MoveToNextLine) || keyEvent->matches(QKeySequence::SelectNextLine)
+            || keyEvent->matches(QKeySequence::MoveToPreviousLine) || keyEvent->matches(QKeySequence::SelectPreviousLine)
+            || keyEvent->matches(QKeySequence::MoveToNextPage) || keyEvent->matches(QKeySequence::SelectNextPage)
+            || keyEvent->matches(QKeySequence::MoveToPreviousPage) || keyEvent->matches(QKeySequence::SelectPreviousPage) || keyEvent->key() == Qt::Key_Enter
+            || keyEvent->key() == Qt::Key_Return) {
             QTreeWidget *first = d->treeWidgets.first();
             if (first) {
                 QApplication::sendEvent(first, event);
@@ -556,7 +543,7 @@ bool KTreeWidgetSearchLine::event(QEvent *event)
 // protected slots
 ////////////////////////////////////////////////////////////////////////////////
 
-void KTreeWidgetSearchLine::Private::_k_queueSearch(const QString &_search)
+void KTreeWidgetSearchLinePrivate::_k_queueSearch(const QString &_search)
 {
     queuedSearches++;
     search = _search;
@@ -564,7 +551,7 @@ void KTreeWidgetSearchLine::Private::_k_queueSearch(const QString &_search)
     QTimer::singleShot(200, q, SLOT(_k_activateSearch()));
 }
 
-void KTreeWidgetSearchLine::Private::_k_activateSearch()
+void KTreeWidgetSearchLinePrivate::_k_activateSearch()
 {
     --queuedSearches;
 
