@@ -1,21 +1,10 @@
-/* This file is part of the KDE libraries
-   Copyright (c) 2003 Scott Wheeler <wheeler@kde.org>
-   Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-   Copyright (c) 2006 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2003 Scott Wheeler <wheeler@kde.org>
+    SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KTREEWIDGETSEARCHLINE_H
@@ -23,6 +12,7 @@
 
 #include <QLineEdit>
 #include <kitemviews_export.h>
+#include <memory>
 
 class QModelIndex;
 class QTreeWidget;
@@ -44,9 +34,6 @@ class KITEMVIEWS_EXPORT KTreeWidgetSearchLine : public QLineEdit
 
     Q_PROPERTY(Qt::CaseSensitivity caseSensitity READ caseSensitivity WRITE setCaseSensitivity)
     Q_PROPERTY(bool keepParentsVisible READ keepParentsVisible WRITE setKeepParentsVisible)
-#if KITEMVIEWS_BUILD_DEPRECATED_SINCE(5, 0)
-    Q_PROPERTY(QString clickMessage READ clickMessage WRITE setClickMessage)
-#endif
 
 public:
     /**
@@ -111,26 +98,6 @@ public:
      */
     QList<QTreeWidget *> treeWidgets() const;
 
-#if KITEMVIEWS_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @return the message set with setClickMessage
-     * @deprecated since 5.0, use QLineEdit::placeholderText() instead.
-     **/
-    KITEMVIEWS_DEPRECATED_VERSION(5, 0, "Use QLineEdit::placeholderText()")
-    QString clickMessage() const { return placeholderText(); }
-#endif
-
-#if KITEMVIEWS_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * This makes the line edit display a grayed-out hinting text as long as
-     * the user didn't enter any text. It is often used as indication about
-     * the purpose of the line edit.
-     * @deprecated since 5.0, use QLineEdit::setPlaceholderText() instead.
-     */
-    KITEMVIEWS_DEPRECATED_VERSION(5, 0, "Use QLineEdit::setPlaceholderText(const QString&))")
-    void setClickMessage(const QString &msg) { setPlaceholderText(msg); }
-#endif
-
 Q_SIGNALS:
     /**
      * This signal is emitted whenever an item gets hidden or unhidden due
@@ -231,8 +198,8 @@ protected:
     virtual bool itemMatches(const QTreeWidgetItem *item, const QString &pattern) const;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
-    */
+     * Re-implemented for internal reasons.  API not affected.
+     */
     void contextMenuEvent(QContextMenuEvent *) override;
 
     /**
@@ -272,9 +239,10 @@ protected:
      * Re-implemented for internal reasons.  API not affected.
      */
     bool event(QEvent *event) override;
+
 private:
-    class Private;
-    Private *const d;
+    friend class KTreeWidgetSearchLinePrivate;
+    std::unique_ptr<class KTreeWidgetSearchLinePrivate> const d;
 
     Q_PRIVATE_SLOT(d, void _k_rowsInserted(const QModelIndex &, int, int) const)
     Q_PRIVATE_SLOT(d, void _k_treeWidgetDeleted(QObject *))
